@@ -1,6 +1,5 @@
 from modulepy.base import ModuleBase, ModuleInformation, ModuleVersion, SharedData, ProcessModule, ThreadModule
 from modulepy.loader import ModuleLoader
-from modulepy.manager import ModuleManager
 
 __all__ = ['ModuleBase', 'ModuleLoader', 'ModuleInformation', 'ModuleVersion', 'SharedData',
-           'ProcessModule', 'ThreadModule', 'ModuleManager']
+           'ProcessModule', 'ThreadModule']
